@@ -26,14 +26,15 @@ def scrape_tweets(class_name: str, query=None, username=None, limit=100):
     # Run
     twint.run.Search(c)
 
-
+    os.makedirs("content/data", exist_ok=True)
     with open("tmp.txt", "r") as f:
         lines = f.readlines()
 
     with open(os.path.join("/content/data", class_name + ".txt"), "w") as f:
-        idx = l.find(">")
-        tweet = l[idx+2:-1]
-    f.write(tweet)
+        for l in lines:
+            idx = l.find(">")
+            tweet = l[idx+2:-1]
+            f.write(tweet)
 
     os.remove("tmp.txt")
 
